#
# spec file for package xfs
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} < 1550
  %define _distconfdir %{_prefix}%{_sysconfdir}
%endif
Name:           xfs
Version:        1.2.2
Release:        1.1
Summary:        X font server
License:        HPND
Group:          System/X11/Utilities
URL:            https://xorg.freedesktop.org/
Source0:        https://xorg.freedesktop.org/releases/individual/app/xfs-%{version}.tar.xz
Source1:        xfs.config
Source2:        xfs.init.d
Source3:        xfs.service
Source10:       https://xorg.freedesktop.org/releases/individual/app/xfs-%{version}.tar.xz.sig
Source11:       xfs.keyring
BuildRequires:  font-util >= 1.1
BuildRequires:  pkgconfig
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(xfont2)
BuildRequires:  pkgconfig(xorg-macros) >= 1.10
BuildRequires:  pkgconfig(xproto) >= 7.0.17
BuildRequires:  pkgconfig(xtrans)
# FIXME: use proper Requires(pre/post/preun/...)
PreReq:         %fillup_prereq
# This was part of the xorg-x11 package up to version 7.6
Conflicts:      xorg-x11 <= 7.6

%description
xfs is the X Window System font server. It supplies fonts to X Window
System display servers.

%prep
%setup -q

%build
%configure --with-default-config-file=%{_sysconfdir}/X11/fs/config,%{_distconfdir}/X11/fs/config CFLAGS="%{optflags} -Wno-error=array-bounds"
%make_build

%install
%make_install
mkdir -p %{buildroot}%{_sbindir} \
         %{buildroot}%{_unitdir}
rm -f %{buildroot}%{_sysconfdir}/X11/fs/config
install -D -m 0644 %{SOURCE1} %{buildroot}%{_distconfdir}/X11/fs/config
install -D -m 0444 %{SOURCE3} %{buildroot}%{_unitdir}/xfs.service
install -D -m 0755 %{SOURCE2} %{buildroot}%{_sbindir}/rcxfs

%pre
%service_add_pre xfs.service

%post
%service_add_post xfs.service

%preun
%service_del_preun xfs.service

%postun
%service_del_postun xfs.service

%files
%license COPYING
%doc ChangeLog README.md
%dir %{_distconfdir}
%dir %{_distconfdir}/X11
%dir %{_distconfdir}/X11/fs
%{_distconfdir}/X11/fs/config
%{_unitdir}/xfs.service
%{_sbindir}/rcxfs
%{_bindir}/xfs
%{_mandir}/man1/xfs.1%{?ext_man}

%changelog
* Tue Jul 30 2024 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.2.2
  * This release fixes a number of compiler warnings, and makes
    other code cleanups and changes to improve code maintainability
    and analyzer output.
* Thu Aug 11 2022 Dirk Müller <dmueller@suse.com>
- modernize spec-file, move license to licensedir
- use gpg for source validation
* Mon Jul 11 2022 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.2.1
  * doc/xfs-design.xml: Remove obsolete B16 tags in struct definition
  * Update README for gitlab migration
  * Update configure.ac bug URL for gitlab migration
  * gitlab CI: add a basic build test
  * Build xz tarballs instead of bzip2
  * Fix spelling/wording issues
  * SetAlternateServers(): avoid memory leak on allocation failure
  * Use memcpy() instead of memmove() when buffers are known not to overlap
  * gitlab CI: stop requiring Signed-off-by in commits
* Mon Jan 10 2022 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Modified:
  * xfs.service
* Tue Jul 13 2021 Stefan Dirsch <sndirsch@suse.com>
- fixed build against latest gcc check changes
* Tue Nov  3 2020 Franck Bui <fbui@suse.com>
- Drop '-f' option with %%service_del_preun/%%service_del_postun
  With %%service_del_preun, the option is already ignored with as
  support for DISABLE_STOP_ON_REMOVAL has been dropped.
  With %%service_del_postun, this option shouldn't be needed besides
  very few special cases. But this package doesn't seem to belong to
  this category.
* Mon Jul 27 2020 Stefan Dirsch <sndirsch@suse.com>
- moved config file to /usr/etc/X11/fs (boo#1173050)
* Sun Jan  5 2020 Stefan Dirsch <sndirsch@suse.com>
- dropped /tmp/.font-unix deletion/creation from the init script
  (boo#1159121)
* Thu Nov 15 2018 sndirsch@suse.com
- switched from init.d script to a native systemd service
  (boo#1116053)
- cleanup in specfile
* Thu Feb  8 2018 sndirsch@suse.com
- fixed build (looks like a manual page has been dropped)
* Tue Nov 28 2017 sndirsch@suse.com
- xfs 1.2.0
  * This release ports the X Font Server to libXfont 2.x.
    Distributions may now drop libXfont 1.x at their convenience.
    This conversion has been lightly tested but some issues may
    remain; please report any new issues to xorg-devel@lists.x.org.
* Tue May 30 2017 sndirsch@suse.com
- includes everything needed for missing sle issue entries:
  fate #320388 (bsc#1041620)
* Mon Aug 25 2014 sndirsch@suse.com
- xfs 1.1.4
  * This release improves compatibility with libXfont 1.5 and
    cleans up many compiler warnings and chunks of dead code.
  * supersedes U_Only-call-SnfSetFormat-if-libXfont-is-built-with-SNF.patch
* Tue Jul 15 2014 sndirsch@suse.com
- U_Only-call-SnfSetFormat-if-libXfont-is-built-with-SNF.patch
  * needed after switching to libXfont 1.8, which now disables
    support for SNF font format by default
* Wed Mar 19 2014 sndirsch@suse.com
- udpated to current git id 2c79452 in order to fix build for
  latest libXfont
* Wed Jun 12 2013 cfarrell@suse.com
- license update: HPND
  This is HPND, not MIT (absence of express sublicensing permission etc)
* Tue May  7 2013 sndirsch@suse.com
- xfs 1.1.3
  * This release contains a number of code cleanups and other
    minor fixes.
* Fri May 11 2012 sndirsch@suse.com
- make use of %%verfiy(not md5 size mtime) for /etc/X11/fs/config
  (bnc#761824)
* Fri Apr 13 2012 vuntz@opensuse.org
- Update to version 1.1.2:
  + Fix issues found by static analysis and compiler warnings
  + Code & doc cleanups
  + Build configuration improvements
- Add pkgconfig(xproto) BuildRequires: new upstream dependency.
- Remove pkgconfig(libfs) BuildRequires: dependency has been
  removed.
- Call %%restart_on_update for xfs in %%postun, as recommended by
  packaging guidelines.
* Fri Apr 13 2012 vuntz@opensuse.org
- Split xfs from xorg-x11. Initial version: 1.1.1.
